@@ -29,6 +29,7 @@ class AppGui:
         self.saved_file = False
         self.raw_output = {}
         self.clean_output = {}
+        self.formatted_output = None
         self.collector = event_handler.Collector("gui", 1)
         self.collector_report = {}
         self.running_thread = None
@@ -262,7 +263,7 @@ class AppGui:
         # Reinit the frame to open buttons
         self.init_record_frame()
 
-    def format_output(self):
+    def format_output(self, final=False):
         """ Use jinja templates to format output according to selection. """
         # Some of the formats are created with the help of jinja templates. The following lines
         # initiate the template environment.
@@ -278,21 +279,25 @@ class AppGui:
         # Format the output.
         # If raw or json format is required, we will just pass the stored
         # data, that we have got from the recording session.
+        if final == True:
+            skip = False
+        else:
+            skip = True
         if self.choices['format'] == "raw":
             source = self.raw_output
         elif self.choices['format'] == "json":
             source = self.clean_output
         # For other formats, we use the translator.
         elif self.choices['format'] == "adoc":
-            lines = translate.polish_data(lang="adoc", skip=True)
+            lines = translate.polish_data(lang="adoc", skip=skip)
             template = templates.get_template('page.adoc')
             source = template.render(title="Recorded workflow", report=lines)
         elif self.choices['format'] == "html":
-            lines = translate.polish_data(lang="html", skip=True)
+            lines = translate.polish_data(lang="html", skip=skip)
             template = templates.get_template('page.html')
             source = template.render(title="Recorded workflow", report=lines)
         elif self.choices['format'] == "pm":
-            lines = translate.polish_data(lang="openqa", skip=True)
+            lines = translate.polish_data(lang="openqa", skip=skip)
             template = templates.get_template('page.pm')
             source = template.render(title="Recorded workflow", report=lines)
         # Return formatted output
@@ -305,7 +310,7 @@ class AppGui:
         filename = f"{self.choices['filename']}.{self.choices['format']}"
         filename = os.path.join(self.choices['path'], filename)
         # Format the output
-        source = self.format_output()
+        source = self.format_output(final=True)
         # Write it into the file
         with open(filename, 'w') as target:
             if self.choices['format'] == "raw" or self.choices['format'] == "json":
@@ -770,7 +775,7 @@ class AppGui:
         # The format is selected based on the value in self.choices.
         # It can be altered using the Format menu, or using the New
         # File menu item.
-        output = self.format_output()
+        output = self.format_output(final=False)
         self.text.delete("1.0", END)
         self.text.insert("1.0", f"---- Workflow report in {self.choices['format']} ----\n\n")
         self.text.insert(END, output)
